@@ -1,4 +1,12 @@
-#!/bin/env perl
+#!/usr/bin/env perl
+
+# Save WSDL and XSD files from the network into the current directory, with
+# subdirectories created for the protocol (http or https), host name(s), and
+# paths to the loaded documents.
+#
+# example usage:
+#
+#     $ perl save_wsdl_schema.pl <URLs of WSDL and XSD files...>
 
 use Modern::Perl '2010';
 use LWP::UserAgent;
@@ -8,10 +16,14 @@ use XML::Compile::WSDL11;
 use XML::Compile::SOAP11;
 use XML::CompileX::Schema::Loader;
 
+# create a user agent that will save content to the filesystem
 my $user_agent = LWP::UserAgent->new;
 $user_agent->set_my_handler( response_done => \&response_done_handler );
 my $transport
     = XML::Compile::Transport::SOAPHTTP->new( user_agent => $user_agent );
+
+# use XML::CompileX::Schema::Loader to collect WSDL and XSD files from URIs
+# on the command line
 my $wsdl   = XML::Compile::WSDL11->new;
 my $loader = XML::CompileX::Schema::Loader->new(
     uris       => \@ARGV,
@@ -19,14 +31,18 @@ my $loader = XML::CompileX::Schema::Loader->new(
     wsdl       => $wsdl,
 );
 $loader->collect_imports;
+
+# make sure all calls compile
 $wsdl->compileCalls( transport => $transport );
 
+# LWP handler that saves content based on its path on the server
 sub response_done_handler {
     my ( $response, $ua, $h ) = @_;
 
+    my $uri  = $response->base->canonical;
     my $path = Path::Tiny->cwd->child(
         grep    {$_}
-            map { $response->base->canonical->$_ }
+            map { $uri->abs($uri)->$_ }
             qw(scheme authority path_segments query fragment),
     );
 
